==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_text.js <==
/*****************************************************
 * Extension script: TextArea form object
 *
 * INHERITS FROM obj_form_generic
 *    _me._value
 *    _me._disabled
 *    _me.__update
 *
 * @Date: 16.4.2006 16:33:51
 *****************************************************/
 
_me = obj_text.prototype;
function obj_text(){};

/**
 * @brief: CONSTRUCTOR, create textarea form object to __eIN variable
 * @date : 20.4.2006 17:24:21
 **/
_me.__constructor = function(){
	/* creates ELM directly, because simlicity of object */
	var elm = mkElement('textarea',{"name":this._pathName+'main',"id":this._pathName+'main',"className":this._type});
    	elm.setAttribute('wrap','off');
    
	this._main.appendChild(elm);

	this.__eIN = elm.form[elm.name];

	var me = this;
	this._main.onfocus = function(er){
		me.__eIN.focus();
	}
};
/**
 * @brief	: activate value restrictions
 * @example	:
 *		_restrict('regExp','error string',...)
 *		"error string" is optional parametr
 * @date	: 25.4.2006 15:59:31
 **/
_me._restrict = function(){
	if (!arguments.length) {
		this.__eIN.onkeyup = null;
		this.__restrictions  = null;
		return;
	}

	this.__restrictions = arguments;

	var me = this;
	this.__eIN.onkeyup = function(){ me.__check(); };
	this.__check();
};

/**
 * @brief: value check function
 * @date : 25.4.2006 16:04:17
 **/
_me.__check = function(){
	if (!this.__restrictions || !this.__restrictions.length) {
		removecss(this._main,'error');
		return true;
	}

	var r = this.__restrictions, v = this._value(), x;

	this._checkError = [];

	for (var i = 0;i<r.length;i++){
		if (i%2) continue;
		var re = r[i];

		if (re.indexOf(">")==0)
			if(v.length>re.substr(1)) continue;
		else if (re.indexOf("<")==0){
			if (v.length<re.substr(1)) continue;
		}
		else{
			x = new RegExp(re,'gi');
			if (v.match(x)) continue;
		}

		this._checkError.push(r[i+1]);
		addcss(this._main,'error');
		return false;
	}

	removecss(this._main,'error');
	return true;
};

_me._nowrap = function(b){
	this.__eIN.setAttribute('wrap',b?'off':'soft');
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_text.js <==
/*****************************************************
 * Extension script: TextArea form object
 *
 * INHERITS FROM obj_form_generic
 *    _me._value
 *    _me._disabled
 *    _me.__update
 *
 * @Date: 16.4.2006 16:33:51
 *****************************************************/
 
_me = obj_text.prototype;
function obj_text(){};

/**
 * @brief: CONSTRUCTOR, create textarea form object to __eIN variable
 * @date : 20.4.2006 17:24:21
 **/
_me.__constructor = function(){
	/* creates ELM directly, because simlicity of object */
	var elm = mkElement('textarea',{"name":this._pathName+'main',"id":this._pathName+'main'});
	elm.setAttribute('wrap','off');

	this._main.appendChild(elm);
	elm.className = this._type;

	this.__eIN = elm.form[elm.name];

	var me = this;
	this._main.onfocus = function(er){
		me.__eIN.focus();
	}
};
/**
 * @brief	: activate value restrictions
 * @example	:
 *		_restrict('regExp','error string',...)
 *		"error string" is optional parametr
 * @date	: 25.4.2006 15:59:31
 **/
_me._restrict = function(){
	if (!arguments.length) {
		this.__eIN.onkeyup = null;
		this.__restrictions  = null;
		return;
	}

	this.__restrictions = arguments;
	var me = this;
	this.__eIN.onkeyup = function(){ me.__check(); };
	this.__check();
};


/**
 * @brief: value check function
 * @date : 25.4.2006 16:04:17
 **/
_me.__check = function(){
	if (!this.__restrictions || !this.__restrictions.length) {
		removecss(this._main,'error');
		return true;
	}

	var r = this.__restrictions, v = this._value(), x;

	this._checkError = [];

	for (var i = 0;i<r.length;i++){
		if (i%2) continue;
		var re = r[i];

		if (re.indexOf(">")==0)
			if(v.length>re.substr(1)) continue;
		else if (re.indexOf("<")==0){
			if (v.length<re.substr(1)) continue;
		}
		else{
			x = new RegExp(re,'gi');
			if (v.match(x)) continue;
		}

		this._checkError.push(r[i+1]);
		addcss(this._main,'error');
		return false;
	}

	removecss(this._main,'error');
	return true;
};

_me._nowrap = function(b){
	this.__eIN.setAttribute('wrap',b?'off':'soft');
};
